summaryrefslogtreecommitdiffstats
path: root/whine.pl
diff options
context:
space:
mode:
Diffstat (limited to 'whine.pl')
-rwxr-xr-xwhine.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/whine.pl b/whine.pl
index 0642ec5ab..8be68f42c 100755
--- a/whine.pl
+++ b/whine.pl
@@ -99,13 +99,13 @@ if (Param('shutdownhtml')) {
}
# Send whines from the address in the 'mailfrom' Parameter so that all
# Bugzilla-originated mail appears to come from a single address.
-my $fromaddress = Param('mailfrom');
+my $fromaddress = Param('maintainer');
if ($fromaddress !~ Param('emailregexp')) {
die "Cannot run. " .
- "The Bugzilla email address has not been properly set!\n";
+ "The maintainer email address has not been properly set!\n";
}
# Check the nomail file for users who should not receive mail
@@ -99,13 +99,13 @@ if (Param('shutdownhtml')) {
}
-# Send whines from the address in the 'mailfrom' Parameter so that all
+# Send whines from the address in the 'maintainer' Parameter so that all
# Bugzilla-originated mail appears to come from a single address.